diff --git a/CMakeLists.txt b/CMakeLists.txt
index 185a3e8097..5f8fa0653a 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -805,7 +805,7 @@ set(CPACK_PACKAGE_VERSION_MAJOR ${DOLPHIN_VERSION_MAJOR})
set(CPACK_PACKAGE_VERSION_MINOR ${DOLPHIN_VERSION_MINOR})
set(CPACK_PACKAGE_VERSION_PATCH ${DOLPHIN_VERSION_PATCH})
set(CPACK_PACKAGE_DESCRIPTION_FILE ${PROJECT_SOURCE_DIR}/Data/cpack_package_description.txt)
-set(CPACK_PACKAGE_DESCRIPTION_SUMMARY "A Gamecube, Wii and Triforce emulator")
+set(CPACK_PACKAGE_DESCRIPTION_SUMMARY "A GameCube, Wii and Triforce emulator")
set(CPACK_RPM_PACKAGE_GROUP System/Emulators/Other)
set(CPACK_RPM_PACKAGE_LICENSE GPL-2.0)
diff --git a/Data/cpack_package_description.txt b/Data/cpack_package_description.txt
index 318774314d..9db61bc885 100644
--- a/Data/cpack_package_description.txt
+++ b/Data/cpack_package_description.txt
@@ -1 +1 @@
-Dolphin is a Gamecube, Wii and Triforce (the arcade machine based on the Gamecube) emulator which supports many extra features and abilities not present on the original consoles. Gamecube and Wii compatibility is good - one can expect "mainstream" titles to run; lesser known titles can be hit or miss. Triforce compatibility is currently limited to a couple of games - others require more of the Triforce-specific peripheral devices to be emulated.
+Dolphin is a GameCube, Wii and Triforce (the arcade machine based on the GameCube) emulator which supports many extra features and abilities not present on the original consoles. GameCube and Wii compatibility is good - one can expect "mainstream" titles to run; lesser known titles can be hit or miss. Triforce compatibility is currently limited to a couple of games - others require more of the Triforce-specific peripheral devices to be emulated.
diff --git a/Languages/po/dolphin-emu.pot b/Languages/po/dolphin-emu.pot
index 0cc7ca287a..92eb6ab6cf 100644
--- a/Languages/po/dolphin-emu.pot
+++ b/Languages/po/dolphin-emu.pot
@@ -576,7 +576,7 @@ msgid "All GC/Wii images (gcm, iso, wbfs, ciso, gcz)"
msgstr ""
#: Source/Core/DolphinWX/GameListCtrl.cpp:1208
-msgid "All Gamecube GCM files (gcm)"
+msgid "All GameCube GCM files (gcm)"
msgstr ""
#: Source/Core/DolphinWX/FrameTools.cpp:1533
@@ -1200,7 +1200,7 @@ msgstr ""
#, c-format
msgid ""
"Could not read \"%s\". There is no disc in the drive, or it is not a GC/Wii "
-"backup. Please note that original Gamecube and Wii discs cannot be read by "
+"backup. Please note that original GameCube and Wii discs cannot be read by "
"most PC DVD drives."
msgstr ""
@@ -1557,7 +1557,7 @@ msgid ""
"Revision: %s\n"
"Compiled: %s @ %s\n"
"\n"
-"Dolphin is a Gamecube/Wii emulator, which was\n"
+"Dolphin is a GameCube/Wii emulator, which was\n"
"originally written by F|RES and ector.\n"
"Today Dolphin is an open source project with many\n"
"contributors, too many to list.\n"
@@ -1577,7 +1577,7 @@ msgid ""
"Thanks to hcs/destop for their GC ADPCM decoder.\n"
"\n"
"We are not affiliated with Nintendo in any way.\n"
-"Gamecube and Wii are trademarks of Nintendo.\n"
+"GameCube and Wii are trademarks of Nintendo.\n"
"The emulator should not be used to play games\n"
"you do not legally own."
msgstr ""
@@ -2529,20 +2529,20 @@ msgid "GameCube Savegame files(*.gci;*.gcs;*.sav)"
msgstr ""
#: Source/Core/DolphinWX/ConfigMain.cpp:559
-msgid "Gamecube"
+msgid "GameCube"
msgstr ""
#: Source/Core/DolphinWX/FrameTools.cpp:220
-msgid "Gamecube &Pad Settings"
+msgid "GameCube &Pad Settings"
msgstr ""
#: Source/Core/DolphinWX/MemcardManager.cpp:231
#: Source/Core/DolphinWX/ConfigMain.cpp:1060
-msgid "Gamecube Memory Cards (*.raw,*.gcp)"
+msgid "GameCube Memory Cards (*.raw,*.gcp)"
msgstr ""
#: Source/Core/DolphinWX/FrameTools.cpp:524
-msgid "Gamecube Pad settings"
+msgid "GameCube Pad settings"
msgstr ""
#: Source/Core/DolphinWX/ISOProperties.cpp:384
diff --git a/Readme.md b/Readme.md
index 3c236427b9..abf0a1a2bf 100644
--- a/Readme.md
+++ b/Readme.md
@@ -1,8 +1,8 @@
-# Dolphin - A Gamecube / Triforce / Wii Emulator
+# Dolphin - A GameCube / Triforce / Wii Emulator
[Homepage](https://dolphin-emu.org/) | [Project Site](https://github.com/dolphin-emu/dolphin) | [Forums](https://forums.dolphin-emu.org/) | [Wiki](https://wiki.dolphin-emu.org/) | [Issue Tracker](https://code.google.com/p/dolphin-emu/issues/list)
-Dolphin is an emulator for running Gamecube, Triforce and Wii games on
+Dolphin is an emulator for running GameCube, Triforce and Wii games on
Windows/Linux/OS X systems and recent Android devices. It's licensed under
the terms of the GNU General Public License, version 2 (GPLv2).
diff --git a/Source/Android/res/values-ja/strings.xml b/Source/Android/res/values-ja/strings.xml
index b9b426aded..d798a35652 100644
--- a/Source/Android/res/values-ja/strings.xml
+++ b/Source/Android/res/values-ja/strings.xml
@@ -82,7 +82,7 @@
Wiiリモコンを有効
入力バインディング
%1$sにバインドするための入力を移動または押してください。
-
+
Aボタン
Bボタン
スタートボタン
diff --git a/Source/Android/res/values/strings.xml b/Source/Android/res/values/strings.xml
index 5f7318dbaa..06de05ae27 100644
--- a/Source/Android/res/values/strings.xml
+++ b/Source/Android/res/values/strings.xml
@@ -68,7 +68,7 @@
Input
Input Overlay Layout
Button layout for the input overlay.
- Gamecube Controller Bindings
+ GameCube Controller Bindings
Controller 1
Controller 2
Controller 3
@@ -82,7 +82,7 @@
Enable Wiimote
Input Binding
Press or move an input to bind it to %1$s.
-
+
Button A
Button B
Button Start
diff --git a/Source/Android/res/xml/input_prefs.xml b/Source/Android/res/xml/input_prefs.xml
index ad4b5e7130..6e422f49c1 100644
--- a/Source/Android/res/xml/input_prefs.xml
+++ b/Source/Android/res/xml/input_prefs.xml
@@ -11,7 +11,7 @@
android:targetClass="org.dolphinemu.dolphinemu.settings.input.overlayconfig.OverlayConfigActivity"/>
-
+
diff --git a/Source/Core/Core/ARDecrypt.cpp b/Source/Core/Core/ARDecrypt.cpp
index 04be8757e2..7867e0511a 100644
--- a/Source/Core/Core/ARDecrypt.cpp
+++ b/Source/Core/Core/ARDecrypt.cpp
@@ -3,7 +3,7 @@
// Refer to the license.txt file included.
// Most of the code in this file is from:
-// GCNcrypt - Gamecube AR Crypto Program
+// GCNcrypt - GameCube AR Crypto Program
// Copyright (C) 2003-2004 Parasyte
#include
diff --git a/Source/Core/Core/Core.cpp b/Source/Core/Core/Core.cpp
index 87d6cdd9c0..5e5dc7318c 100644
--- a/Source/Core/Core/Core.cpp
+++ b/Source/Core/Core/Core.cpp
@@ -199,7 +199,7 @@ bool Init()
g_CoreStartupParameter = _CoreParameter;
INFO_LOG(OSREPORT, "Starting core = %s mode",
- g_CoreStartupParameter.bWii ? "Wii" : "Gamecube");
+ g_CoreStartupParameter.bWii ? "Wii" : "GameCube");
INFO_LOG(OSREPORT, "CPU Thread separate = %s",
g_CoreStartupParameter.bCPUThread ? "Yes" : "No");
diff --git a/Source/Core/Core/CoreParameter.cpp b/Source/Core/Core/CoreParameter.cpp
index 630ab4c5b3..5a213b5e92 100644
--- a/Source/Core/Core/CoreParameter.cpp
+++ b/Source/Core/Core/CoreParameter.cpp
@@ -140,7 +140,7 @@ bool SCoreStartupParameter::AutoSetup(EBootBS2 _BootBS2)
if (bootDrive)
PanicAlertT("Could not read \"%s\". "
"There is no disc in the drive, or it is not a GC/Wii backup. "
- "Please note that original Gamecube and Wii discs cannot be read "
+ "Please note that original GameCube and Wii discs cannot be read "
"by most PC DVD drives.", m_strFilename.c_str());
else
PanicAlertT("\"%s\" is an invalid GCM/ISO file, or is not a GC/Wii ISO.",
diff --git a/Source/Core/Core/HW/DSPHLE/UCodes/AX.h b/Source/Core/Core/HW/DSPHLE/UCodes/AX.h
index 194f0d671f..08b5dd4951 100644
--- a/Source/Core/Core/HW/DSPHLE/UCodes/AX.h
+++ b/Source/Core/Core/HW/DSPHLE/UCodes/AX.h
@@ -2,7 +2,7 @@
// Licensed under GPLv2
// Refer to the license.txt file included.
-// High-level emulation for the AX Gamecube UCode.
+// High-level emulation for the AX GameCube UCode.
//
// TODO:
// * Depop support
diff --git a/Source/Core/Core/HW/DVDInterface.cpp b/Source/Core/Core/HW/DVDInterface.cpp
index ace88f8072..53e8ebfef8 100644
--- a/Source/Core/Core/HW/DVDInterface.cpp
+++ b/Source/Core/Core/HW/DVDInterface.cpp
@@ -21,7 +21,7 @@
#include "Core/HW/SystemTimers.h"
#include "Core/PowerPC/PowerPC.h"
-// A Gamecube disc can be read at somewhere between
+// A GameCube disc can be read at somewhere between
// 2 and 3MB/sec, depending on the location on disk. Wii disks
// not yet tested.
static const u32 DISC_TRANSFER_RATE_GC = 3 * 1024 * 1024;
diff --git a/Source/Core/Core/HW/SystemTimers.cpp b/Source/Core/Core/HW/SystemTimers.cpp
index 2e11422a91..41b18ef0fe 100644
--- a/Source/Core/Core/HW/SystemTimers.cpp
+++ b/Source/Core/Core/HW/SystemTimers.cpp
@@ -85,7 +85,7 @@ namespace SystemTimers
u32 CPU_CORE_CLOCK = 486000000u; // 486 mhz (its not 485, stop bugging me!)
/*
-Gamecube MHz
+GameCube MHz
flipper <-> ARAM bus: 81 (DSP)
gekko <-> flipper bus: 162
flipper <-> 1T-SRAM bus: 324
diff --git a/Source/Core/Core/Movie.cpp b/Source/Core/Core/Movie.cpp
index df33528de4..f8fa16a0ff 100644
--- a/Source/Core/Core/Movie.cpp
+++ b/Source/Core/Core/Movie.cpp
@@ -1045,7 +1045,7 @@ bool PlayWiimote(int wiimote, u8 *data, const WiimoteEmu::ReportFeatures& rptf,
if (size != sizeInMovie)
{
PanicAlertT("Fatal desync. Aborting playback. (Error in PlayWiimote: %u != %u, byte %u.)%s", (u32)sizeInMovie, (u32)size, (u32)g_currentByte,
- (g_numPads & 0xF)?" Try re-creating the recording with all GameCube controllers disabled (in Configure > Gamecube > Device Settings)." : "");
+ (g_numPads & 0xF)?" Try re-creating the recording with all GameCube controllers disabled (in Configure > GameCube > Device Settings)." : "");
EndPlayInput(!g_bReadOnly);
return false;
}
diff --git a/Source/Core/Core/Movie.h b/Source/Core/Core/Movie.h
index a317b0b01b..e1ad427987 100644
--- a/Source/Core/Core/Movie.h
+++ b/Source/Core/Core/Movie.h
@@ -29,7 +29,7 @@ enum PlayMode
MODE_PLAYING
};
-// Gamecube Controller State
+// GameCube Controller State
#pragma pack(push,1)
struct ControllerState
{
diff --git a/Source/Core/Core/NetPlayClient.cpp b/Source/Core/Core/NetPlayClient.cpp
index 8e9742e65a..f15837116d 100644
--- a/Source/Core/Core/NetPlayClient.cpp
+++ b/Source/Core/Core/NetPlayClient.cpp
@@ -563,9 +563,9 @@ bool NetPlayClient::GetNetPads(const u8 pad_nb, const SPADStatus* const pad_stat
// The interface for this is extremely silly.
//
// Imagine a physical device that links three Gamecubes together
- // and emulates NetPlay that way. Which Gamecube controls which
+ // and emulates NetPlay that way. Which GameCube controls which
// in-game controllers can be configured on the device (m_pad_map)
- // but which sockets on each individual Gamecube should be used
+ // but which sockets on each individual GameCube should be used
// to control which players? The solution that Dolphin uses is
// that we hardcode the knowledge that they go in order, so if
// you have a 3P game with three gamecubes, then every single
diff --git a/Source/Core/Core/PowerPC/Interpreter/Interpreter_SystemRegisters.cpp b/Source/Core/Core/PowerPC/Interpreter/Interpreter_SystemRegisters.cpp
index a738e59056..b81334e189 100644
--- a/Source/Core/Core/PowerPC/Interpreter/Interpreter_SystemRegisters.cpp
+++ b/Source/Core/Core/PowerPC/Interpreter/Interpreter_SystemRegisters.cpp
@@ -209,7 +209,7 @@ void Interpreter::mfspr(UGeckoInstruction _inst)
//TODO - check processor privilege level - many of these require privilege
//XER LR CTR are the only ones available in user mode, time base can be read too.
- //Gamecube games always run in superuser mode, but hey....
+ //GameCube games always run in superuser mode, but hey....
switch (iIndex)
{
@@ -248,7 +248,7 @@ void Interpreter::mtspr(UGeckoInstruction _inst)
//TODO - check processor privilege level - many of these require privilege
//XER LR CTR are the only ones available in user mode, time base can be read too.
- //Gamecube games always run in superuser mode, but hey....
+ //GameCube games always run in superuser mode, but hey....
//Our DMA emulation is highly inaccurate - instead of properly emulating the queue
//and so on, we simply make all DMA:s complete instantaneously.
diff --git a/Source/Core/Core/PowerPC/PowerPC.cpp b/Source/Core/Core/PowerPC/PowerPC.cpp
index 1bd18de347..db4e755de4 100644
--- a/Source/Core/Core/PowerPC/PowerPC.cpp
+++ b/Source/Core/Core/PowerPC/PowerPC.cpp
@@ -360,7 +360,7 @@ void CheckExceptions()
}
else if (exceptions & EXCEPTION_FPU_UNAVAILABLE)
{
- //This happens a lot - Gamecube OS uses deferred FPU context switching
+ //This happens a lot - GameCube OS uses deferred FPU context switching
SRR0 = PC; // re-execute the instruction
SRR1 = MSR & 0x87C0FFFF;
MSR |= (MSR >> 16) & 1;
diff --git a/Source/Core/DiscIO/VolumeCreator.cpp b/Source/Core/DiscIO/VolumeCreator.cpp
index bb5aeb31a1..71b41e19e7 100644
--- a/Source/Core/DiscIO/VolumeCreator.cpp
+++ b/Source/Core/DiscIO/VolumeCreator.cpp
@@ -132,7 +132,7 @@ bool IsVolumeWiiDisc(const IVolume *_rVolume)
_rVolume->Read(0x18, 4, (u8*)&MagicWord);
return (Common::swap32(MagicWord) == 0x5D1C9EA3);
- //Gamecube 0xc2339f3d
+ //GameCube 0xc2339f3d
}
bool IsVolumeWadFile(const IVolume *_rVolume)
diff --git a/Source/Core/DolphinWX/AboutDolphin.cpp b/Source/Core/DolphinWX/AboutDolphin.cpp
index 470baea8f6..50ececcd84 100644
--- a/Source/Core/DolphinWX/AboutDolphin.cpp
+++ b/Source/Core/DolphinWX/AboutDolphin.cpp
@@ -38,7 +38,7 @@ AboutDolphin::AboutDolphin(wxWindow *parent, wxWindowID id,
"Revision: %s\n"
"Compiled: %s @ %s\n"
"\n"
- "Dolphin is a Gamecube/Wii emulator, which was\n"
+ "Dolphin is a GameCube/Wii emulator, which was\n"
"originally written by F|RES and ector.\n"
"Today Dolphin is an open source project with many\n"
"contributors, too many to list.\n"
@@ -58,7 +58,7 @@ AboutDolphin::AboutDolphin(wxWindow *parent, wxWindowID id,
"Thanks to hcs/destop for their GC ADPCM decoder.\n"
"\n"
"We are not affiliated with Nintendo in any way.\n"
- "Gamecube and Wii are trademarks of Nintendo.\n"
+ "GameCube and Wii are trademarks of Nintendo.\n"
"The emulator should not be used to play games\n"
"you do not legally own."),
scm_desc_str, scm_branch_str, scm_rev_git_str, __DATE__, __TIME__);
diff --git a/Source/Core/DolphinWX/MainNoGUI.cpp b/Source/Core/DolphinWX/MainNoGUI.cpp
index 76e7608e15..5fb50e057b 100644
--- a/Source/Core/DolphinWX/MainNoGUI.cpp
+++ b/Source/Core/DolphinWX/MainNoGUI.cpp
@@ -314,7 +314,7 @@ int main(int argc, char* argv[])
if (help == 1 || argc == optind)
{
fprintf(stderr, "%s\n\n", scm_rev_str);
- fprintf(stderr, "A multi-platform Gamecube/Wii emulator\n\n");
+ fprintf(stderr, "A multi-platform GameCube/Wii emulator\n\n");
fprintf(stderr, "Usage: %s [-e ] [-h] [-v]\n", argv[0]);
fprintf(stderr, " -e, --exec Load the specified file\n");
fprintf(stderr, " -h, --help Show this help message\n");
diff --git a/Source/Core/DolphinWX/MemcardManager.cpp b/Source/Core/DolphinWX/MemcardManager.cpp
index 70211ff5dc..f0a9a5fc26 100644
--- a/Source/Core/DolphinWX/MemcardManager.cpp
+++ b/Source/Core/DolphinWX/MemcardManager.cpp
@@ -228,7 +228,7 @@ void CMemcardManager::CreateGUIControls()
m_MemcardPath[slot] = new wxFilePickerCtrl(this, ID_MEMCARDPATH_A + slot,
StrToWxStr(File::GetUserPath(D_GCUSER_IDX)), _("Choose a memory card:"),
- _("Gamecube Memory Cards (*.raw,*.gcp)") + wxString("|*.raw;*.gcp"), wxDefaultPosition, wxDefaultSize, wxFLP_USE_TEXTCTRL|wxFLP_OPEN);
+ _("GameCube Memory Cards (*.raw,*.gcp)") + wxString("|*.raw;*.gcp"), wxDefaultPosition, wxDefaultSize, wxFLP_USE_TEXTCTRL|wxFLP_OPEN);
m_MemcardList[slot] = new CMemcardListCtrl(this, ID_MEMCARDLIST_A + slot, wxDefaultPosition, wxSize(350,400),
wxLC_REPORT | wxSUNKEN_BORDER | wxLC_ALIGN_LEFT | wxLC_SINGLE_SEL, mcmSettings);
diff --git a/Source/Core/VideoBackends/Software/EfbInterface.cpp b/Source/Core/VideoBackends/Software/EfbInterface.cpp
index 0eff1cd226..8187345d89 100644
--- a/Source/Core/VideoBackends/Software/EfbInterface.cpp
+++ b/Source/Core/VideoBackends/Software/EfbInterface.cpp
@@ -556,7 +556,7 @@ namespace EfbInterface
}
}
- // Like CopyToXFB, but we copy directly into the opengl colour texture without going via Gamecube main memory or doing a yuyv conversion
+ // Like CopyToXFB, but we copy directly into the opengl colour texture without going via GameCube main memory or doing a yuyv conversion
void BypassXFB(u8* texture, u32 fbWidth, u32 fbHeight, const EFBRectangle& sourceRc, float Gamma) {
if (fbWidth*fbHeight > 640*568) {
ERROR_LOG(VIDEO, "Framebuffer is too large: %ix%i", fbWidth, fbHeight);
diff --git a/Source/Core/VideoCommon/BPFunctions.cpp b/Source/Core/VideoCommon/BPFunctions.cpp
index 76745e89e0..f903c39917 100644
--- a/Source/Core/VideoCommon/BPFunctions.cpp
+++ b/Source/Core/VideoCommon/BPFunctions.cpp
@@ -18,7 +18,7 @@ namespace BPFunctions
{
// ----------------------------------------------
// State translation lookup tables
-// Reference: Yet Another Gamecube Documentation
+// Reference: Yet Another GameCube Documentation
// ----------------------------------------------
diff --git a/Source/Core/VideoCommon/BPStructs.cpp b/Source/Core/VideoCommon/BPStructs.cpp
index 1ef06c5716..e9fdf1f83c 100644
--- a/Source/Core/VideoCommon/BPStructs.cpp
+++ b/Source/Core/VideoCommon/BPStructs.cpp
@@ -51,7 +51,7 @@ static void BPWritten(const BPCmd& bp)
some bp cases check the changes variable, because they might not have to be updated all the time
NOTE: it seems not all bp cases like checking changes, so calling if (bp.changes == 0 ? false : true)
had to be ditched and the games seem to work fine with out it.
- NOTE2: Yet Another Gamecube Documentation calls them Bypass Raster State Registers but possibly completely wrong
+ NOTE2: Yet Another GameCube Documentation calls them Bypass Raster State Registers but possibly completely wrong
NOTE3: This controls the register groups: RAS1/2, SU, TF, TEV, C/Z, PEC
TODO: Turn into function table. The (future) DisplayList (DL) jit can then call the functions directly,
getting rid of dynamic dispatch. Unfortunately, few games use DLs properly - most\
diff --git a/Source/Core/VideoCommon/TextureDecoder_Generic.cpp b/Source/Core/VideoCommon/TextureDecoder_Generic.cpp
index 30edd16360..e945010f68 100644
--- a/Source/Core/VideoCommon/TextureDecoder_Generic.cpp
+++ b/Source/Core/VideoCommon/TextureDecoder_Generic.cpp
@@ -24,9 +24,9 @@ extern const unsigned char sfont_raw[][9*10];
GC_ALIGNED16(u8 texMem[TMEM_SIZE]);
-// Gamecube/Wii texture decoder
+// GameCube/Wii texture decoder
-// Decodes all known Gamecube/Wii texture formats.
+// Decodes all known GameCube/Wii texture formats.
// by ector
int TexDecoder_GetTexelSizeInNibbles(int format)
diff --git a/Source/Core/VideoCommon/TextureDecoder_x64.cpp b/Source/Core/VideoCommon/TextureDecoder_x64.cpp
index efe116d39a..727b66848f 100644
--- a/Source/Core/VideoCommon/TextureDecoder_x64.cpp
+++ b/Source/Core/VideoCommon/TextureDecoder_x64.cpp
@@ -44,9 +44,9 @@ extern const unsigned char sfont_raw[][9*10];
GC_ALIGNED16(u8 texMem[TMEM_SIZE]);
-// Gamecube/Wii texture decoder
+// GameCube/Wii texture decoder
-// Decodes all known Gamecube/Wii texture formats.
+// Decodes all known GameCube/Wii texture formats.
// by ector
int TexDecoder_GetTexelSizeInNibbles(int format)
diff --git a/docs/ActionReplay/CodeTypesGuide.txt b/docs/ActionReplay/CodeTypesGuide.txt
index 88aa4be163..3a94ce076c 100644
--- a/docs/ActionReplay/CodeTypesGuide.txt
+++ b/docs/ActionReplay/CodeTypesGuide.txt
@@ -1,6 +1,6 @@
omments: 1
-A Compendium of Gamecube Action Replay Code Types
+A Compendium of GameCube Action Replay Code Types
Note: This is note a Complete code type list.
@@ -12,7 +12,7 @@ Kenobi's documentation is recommended reading as it is very complete, precise, a
It should be noted that every decrypted AR code has a basic two-part format that is universal to every code. The first half contains the code type and address to be written to. The second half contains the value to be written.
-The Gamecube has a memory range of 80000000 - 817FFFFF (cached), or C0000000 - C17FFFFF (uncached). However for the sake of simplicity, the AR uses an offset number in the range of 00000000 - 017FFFFF. The code type identifier is an 8-bit value that is applied to the first two digits of the offset. For example, if your offset is 00012345, and you wish to perform a 32-bit write (04), you simply add (04000000) + (00012345) = 04012345.
+The GameCube has a memory range of 80000000 - 817FFFFF (cached), or C0000000 - C17FFFFF (uncached). However for the sake of simplicity, the AR uses an offset number in the range of 00000000 - 017FFFFF. The code type identifier is an 8-bit value that is applied to the first two digits of the offset. For example, if your offset is 00012345, and you wish to perform a 32-bit write (04), you simply add (04000000) + (00012345) = 04012345.
In order to conserve space and simplicity, only the 8-bit code type identifier and particulars of the second half of the code will be explained below, as the method for procuring the first half has already been described above ;)
diff --git a/Source/Core/DolphinWX/ConfigMain.cpp b/Source/Core/DolphinWX/ConfigMain.cpp
index 30f812ef7a..89e23054f3 100644
--- a/Source/Core/DolphinWX/ConfigMain.cpp
+++ b/Source/Core/DolphinWX/ConfigMain.cpp
@@ -278,7 +278,7 @@ void CConfigMain::InitializeGUILists()
arrayStringFor_DSPEngine.Add(_("DSP LLE recompiler"));
arrayStringFor_DSPEngine.Add(_("DSP LLE interpreter (slow)"));
- // Gamecube page
+ // GameCube page
// GC Language arrayStrings
arrayStringFor_GCSystemLang.Add(_("English"));
arrayStringFor_GCSystemLang.Add(_("German"));
@@ -385,11 +385,11 @@ void CConfigMain::InitializeGUIValues()
AddAudioBackends();
- // Gamecube - IPL
+ // GameCube - IPL
GCSystemLang->SetSelection(startup_params.SelectedLanguage);
GCAlwaysHLE_BS2->SetValue(startup_params.bHLE_BS2);
- // Gamecube - Devices
+ // GameCube - Devices
wxArrayString SlotDevices;
SlotDevices.Add(_(DEV_NONE_STR));
SlotDevices.Add(_(DEV_DUMMY_STR));
@@ -525,7 +525,7 @@ void CConfigMain::InitializeGUITooltips()
DSPThread->SetToolTip(_("Run DSP LLE on a dedicated thread (not recommended: might cause freezes)."));
BackendSelection->SetToolTip(_("Changing this will have no effect while the emulator is running!"));
- // Gamecube - Devices
+ // GameCube - Devices
GCEXIDevice[2]->SetToolTip(_("Serial Port 1 - This is the port which devices such as the net adapter use"));
// Wii - Devices
@@ -556,7 +556,7 @@ void CConfigMain::CreateGUIControls()
Notebook->AddPage(GeneralPage, _("General"));
Notebook->AddPage(DisplayPage, _("Interface"));
Notebook->AddPage(AudioPage, _("Audio"));
- Notebook->AddPage(GamecubePage, _("Gamecube"));
+ Notebook->AddPage(GamecubePage, _("GameCube"));
Notebook->AddPage(WiiPage, _("Wii"));
Notebook->AddPage(PathsPage, _("Paths"));
@@ -699,7 +699,7 @@ void CConfigMain::CreateGUIControls()
AudioPage->SetSizerAndFit(sAudioPage);
- // Gamecube page
+ // GameCube page
// IPL settings
GCSystemLang = new wxChoice(GamecubePage, ID_GC_SRAM_LNG, wxDefaultPosition, wxDefaultSize, arrayStringFor_GCSystemLang);
GCAlwaysHLE_BS2 = new wxCheckBox(GamecubePage, ID_GC_ALWAYS_HLE_BS2, _("Skip BIOS"));
@@ -728,7 +728,7 @@ void CConfigMain::CreateGUIControls()
GCSIDevice[2] = new wxChoice(GamecubePage, ID_GC_SIDEVICE2);
GCSIDevice[3] = new wxChoice(GamecubePage, ID_GC_SIDEVICE3);
// Populate the Gamecube page
sGamecubeIPLSettings = new wxGridBagSizer();
sGamecubeIPLSettings->Add(GCAlwaysHLE_BS2, wxGBPosition(0, 0), wxGBSpan(1, 2), wxALL, 5);
sGamecubeIPLSettings->Add(TEXT_BOX(GamecubePage, _("System Language:")),
@@ -1015,16 +1015,16 @@ void CConfigMain::GCSettingsChanged(wxCommandEvent& event)
int exidevice = 0;
switch (event.GetId())
{
- // Gamecube - IPL
+ // GameCube - IPL
case ID_GC_SRAM_LNG:
SConfig::GetInstance().m_LocalCoreStartupParameter.SelectedLanguage = GCSystemLang->GetSelection();
bRefreshList = true;
break;
// Gamecube - IPL Settings
case ID_GC_ALWAYS_HLE_BS2:
SConfig::GetInstance().m_LocalCoreStartupParameter.bHLE_BS2 = GCAlwaysHLE_BS2->IsChecked();
break;
- // Gamecube - Devices
+ // GameCube - Devices
case ID_GC_EXIDEVICE_SP1:
exidevice++;
case ID_GC_EXIDEVICE_SLOTB:
@@ -1057,7 +1057,7 @@ void CConfigMain::ChooseMemcardPath(std::string& strMemcard, bool isSlotA)
StrToWxStr(File::GetUserPath(D_GCUSER_IDX)),
isSlotA ? GC_MEMCARDA : GC_MEMCARDB,
wxEmptyString,
- _("Gamecube Memory Cards (*.raw,*.gcp)") + "|*.raw;*.gcp"));
+ _("GameCube Memory Cards (*.raw,*.gcp)") + "|*.raw;*.gcp"));
if (!filename.empty())
{
@@ -728,7 +728,7 @@ void CConfigMain::CreateGUIControls()
GCSIDevice[2] = new wxChoice(GamecubePage, ID_GC_SIDEVICE2);
GCSIDevice[3] = new wxChoice(GamecubePage, ID_GC_SIDEVICE3);
- // Populate the Gamecube page
+ // Populate the GameCube page
sGamecubeIPLSettings = new wxGridBagSizer();
sGamecubeIPLSettings->Add(GCAlwaysHLE_BS2, wxGBPosition(0, 0), wxGBSpan(1, 2), wxALL, 5);
@@ -1015,16 +1015,16 @@ void CConfigMain::GCSettingsChanged(wxCommandEvent& event)
bRefreshList = true;
break;
- // Gamecube - IPL Settings
+ // GameCube - IPL Settings
case ID_GC_ALWAYS_HLE_BS2:
SConfig::GetInstance().m_LocalCoreStartupParameter.bHLE_BS2 = GCAlwaysHLE_BS2->IsChecked();
diff --git a/Source/Core/DolphinWX/FrameTools.cpp b/Source/Core/DolphinWX/FrameTools.cpp
index e9da74c5fa..0233adc492 100644
--- a/Source/Core/DolphinWX/FrameTools.cpp
+++ b/Source/Core/DolphinWX/FrameTools.cpp
@@ -217,7 +217,7 @@ void CFrame::CreateMenu()
pOptionsMenu->AppendSeparator();
pOptionsMenu->Append(IDM_CONFIG_GFX_BACKEND, _("&Graphics Settings"));
pOptionsMenu->Append(IDM_CONFIG_DSP_EMULATOR, _("&DSP Settings"));
- pOptionsMenu->Append(IDM_CONFIG_PAD_PLUGIN, _("Gamecube &Pad Settings"));
+ pOptionsMenu->Append(IDM_CONFIG_PAD_PLUGIN, _("GameCube &Pad Settings"));
pOptionsMenu->Append(IDM_CONFIG_WIIMOTE_PLUGIN, _("&Wiimote Settings"));
pOptionsMenu->Append(IDM_CONFIG_HOTKEYS, _("&Hotkey Settings"));
if (g_pCodeWindow)
@@ -521,7 +521,7 @@ void CFrame::PopulateToolbar(wxAuiToolBar* ToolBar)
ToolBar->AddTool(wxID_PREFERENCES, _("Config"), m_Bitmaps[Toolbar_ConfigMain], _("Configure..."));
ToolBar->AddTool(IDM_CONFIG_GFX_BACKEND, _("Graphics"), m_Bitmaps[Toolbar_ConfigGFX], _("Graphics settings"));
ToolBar->AddTool(IDM_CONFIG_DSP_EMULATOR, _("DSP"), m_Bitmaps[Toolbar_ConfigDSP], _("DSP settings"));
- ToolBar->AddTool(IDM_CONFIG_PAD_PLUGIN, _("GCPad"), m_Bitmaps[Toolbar_ConfigPAD], _("Gamecube Pad settings"));
+ ToolBar->AddTool(IDM_CONFIG_PAD_PLUGIN, _("GCPad"), m_Bitmaps[Toolbar_ConfigPAD], _("GameCube Pad settings"));
ToolBar->AddTool(IDM_CONFIG_WIIMOTE_PLUGIN, _("Wiimote"), m_Bitmaps[Toolbar_Wiimote], _("Wiimote settings"));
// after adding the buttons to the toolbar, must call Realize() to reflect
@@ -1636,7 +1636,7 @@ void CFrame::UpdateGUI()
m_ToolBar->EnableTool(IDM_STOP, Running || Paused);
m_ToolBar->EnableTool(IDM_TOGGLE_FULLSCREEN, Running || Paused);
m_ToolBar->EnableTool(IDM_SCREENSHOT, Running || Paused);
// Don't allow wiimote config while in Gamecube mode
m_ToolBar->EnableTool(IDM_CONFIG_WIIMOTE_PLUGIN, !RunningGamecube);
}
@@ -1636,7 +1636,7 @@ void CFrame::UpdateGUI()
m_ToolBar->EnableTool(IDM_TOGGLE_FULLSCREEN, Running || Paused);
m_ToolBar->EnableTool(IDM_SCREENSHOT, Running || Paused);
- // Don't allow wiimote config while in Gamecube mode
+ // Don't allow wiimote config while in GameCube mode
m_ToolBar->EnableTool(IDM_CONFIG_WIIMOTE_PLUGIN, !RunningGamecube);
}
diff --git a/Source/Core/DolphinWX/GameListCtrl.cpp b/Source/Core/DolphinWX/GameListCtrl.cpp
index 63d7418337..bac6981bf3 100644
--- a/Source/Core/DolphinWX/GameListCtrl.cpp
+++ b/Source/Core/DolphinWX/GameListCtrl.cpp
@@ -448,7 +448,7 @@ void CGameListCtrl::InsertItemInReportView(long _Index)
std::string const name = rISOFile.GetName(SelectedLanguage);
SetItem(_Index, COLUMN_TITLE, StrToWxStr(name), -1);
// We show the company string on Gamecube only
// On Wii we show the description instead as the company string is empty
std::string const notes = (rISOFile.GetPlatform() == GameListItem::GAMECUBE_DISC) ?
rISOFile.GetCompany() : rISOFile.GetDescription(SelectedLanguage);
@@ -1205,7 +1205,7 @@ void CGameListCtrl::OnCompressGCM(wxCommandEvent& WXUNUSED (event))
if (iso->GetPlatform() == GameListItem::WII_DISC)
FileType = _("All Wii ISO files (iso)") + "|*.iso";
else
- FileType = _("All Gamecube GCM files (gcm)") + "|*.gcm";
+ FileType = _("All GameCube GCM files (gcm)") + "|*.gcm";
path = wxFileSelector(
_("Save decompressed GCM/ISO"),
@@ -448,7 +448,7 @@ void CGameListCtrl::InsertItemInReportView(long _Index)
std::string const name = rISOFile.GetName(SelectedLanguage);
SetItem(_Index, COLUMN_TITLE, StrToWxStr(name), -1);
- // We show the company string on Gamecube only
+ // We show the company string on GameCube only
// On Wii we show the description instead as the company string is empty
std::string const notes = (rISOFile.GetPlatform() == GameListItem::GAMECUBE_DISC) ?